# LeanIX Adapter for SAP Integration Suite
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite#benefits)
  * [Key Features](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite#key-features)
  * [Use Cases](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite#use-cases)
  * [Documentation](https://help.sap.com/docs/leanix/ea/leanix-adapter-for-sap-integration-suite#documentation)


The LeanIX adapter for SAP Integration Suite facilitates and accelerates the implementation time and reduces the complexity of connecting to SAP LeanIX.
